@@ -66,11 +66,7 @@ class popup_add_param(object):
         right_frame = ttk.Frame(frame)
 
         # set icon
-        try:
-            img = PhotoImage(file=os.path.dirname(__file__)+'/../images/icon.gif')
-            self.win.tk.call('wm', 'iconphoto', self.win._w, img)
-        except Exception as err:
-            print(err)
+        self.bfit.set_icon(self.win)
 
         # Key bindings
         self.win.bind('<Control-Key-Return>', self.do_add)
